@@ -483,10 +483,10 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 path: Path<IdParam>,
                 body: TypedBody<<super::#context_type_name<'_> as PaymentProcessor>::ProcessArgs>,
             ) -> Result<HttpResponseOk<Payment<
-                <super::#context_type_name<'_> as PaymentProcessor>::CorrelationID,
-                <super::#context_type_name<'_> as PaymentProcessor>::PrivateData,
-                <super::#context_type_name<'_> as PaymentProcessor>::PublicData,
-                <super::#context_type_name<'_> as PaymentProcessor>::ProcessArgs
+                <super::#context_type_name<'static> as PaymentProcessor>::CorrelationID,
+                <super::#context_type_name<'static> as PaymentProcessor>::PrivateData,
+                <super::#context_type_name<'static> as PaymentProcessor>::PublicData,
+                <super::#context_type_name<'static> as PaymentProcessor>::ProcessArgs
             >>, HttpError> {
                 let path_params = path.into_inner();
                 let args = body.into_inner();
